@@ -1,6 +1,6 @@
 // package.json
 var name = "anywidget";
-var version = "0.0.1";
+var version = "0.0.3";
 
 // src/widget.js
 function widget_default(base) {
@@ -14,19 +14,24 @@ function widget_default(base) {
   }
   class AnyView extends base.DOMWidgetView {
     async render() {
-      let mod = await this.#load_esm().catch((err) => {
-        console.error("Failed to load `anywidget` ESM");
-        throw err;
-      });
-      mod.render(this);
-    }
-    #load_esm() {
-      let _module = this.model.get("_module");
-      let uri = _module.startsWith("http://") ? _module : `data:text/javascript;base64, ${btoa(_module)}`;
-      return import(
-        /* webpackIgnore: true */
-        uri
-      );
+      let widget;
+      let esm = this.model.get("_module");
+      if (esm.startsWith("http://") || esm.startsWith("https://")) {
+        widget = await import(
+          /* webpackIgnore: true */
+          esm
+        );
+      } else {
+        let url = URL.createObjectURL(
+          new Blob([esm], { type: "text/javascript" })
+        );
+        widget = await import(
+          /* webpackIgnore: true */
+          url
+        );
+        URL.revokeObjectURL(url);
+      }
+      await widget.render(this);
     }
   }
   return { AnyModel, AnyView };
